==> apiconnect-ui-projects-2.0.11.tgz: package/src/openapi-settings-controller.js <==
/********************************************************* {COPYRIGHT-TOP} ***
 * Licensed Materials - Property of IBM
 * 5725-Z22, 5725-Z63, 5725-U33, 5725-Z63
 *
 * (C) Copyright IBM Corporation 2017
 *
 * All Rights Reserved.
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 ********************************************************** {COPYRIGHT-END} **/
module.exports = [
  '$scope',
  '$log',
  '$rootScope',
  '$state',
  '$window',
  '$localStorage',
  'ProjectsServices',
  'ConfigServices',
  'OpenAPIWorkspace',
  '$modalInstance',
  function OpenApiSettingsController(
  $scope,
  $log,
  $rootScope,
  $state,
  $window,
  $localStorage,
  ProjectsServices,
  ConfigServices,
  OpenAPIWorkspace,
  $modalInstance
) {
  'use strict';

  $scope.newProject = $rootScope.activeProject;
  $scope.master = angular.copy($scope.newProject);

  $scope.updateOpenApiProject = function(form){
    if (form.$invalid) {
      return;
    }

    ProjectsServices.updateProject($scope.newProject)
      .then(function(result){
        return ProjectsServices.setProjectEnvironment(result.data)
          .then(function(project) {
            $rootScope.activeProject = project;
            $rootScope.workspaceDir = project;
          });
      })
      .then(function(){
        $rootScope.$emit('event:getProjects');
        $modalInstance.close();
      });
  };

  $scope.cancelProjectSettings = function(){
    angular.copy($scope.master, $scope.newProject);
    $modalInstance.close();
  }
}];

==> apiconnect-ui-projects-3.0.2.tgz: package/src/openapi-settings-controller.js <==
/********************************************************* {COPYRIGHT-TOP} ***
 * Licensed Materials - Property of IBM
 * 5725-Z22, 5725-Z63, 5725-U33, 5725-Z63
 *
 * (C) Copyright IBM Corporation 2017
 *
 * All Rights Reserved.
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 ********************************************************** {COPYRIGHT-END} **/
module.exports = [
  '$scope',
  '$log',
  '$rootScope',
  '$state',
  '$window',
  '$localStorage',
  'ProjectsServices',
  'ConfigServices',
  'OpenAPIWorkspace',
  '$uibModalInstance',
  function OpenApiSettingsController(
  $scope,
  $log,
  $rootScope,
  $state,
  $window,
  $localStorage,
  ProjectsServices,
  ConfigServices,
  OpenAPIWorkspace,
  $uibModalInstance
) {
  'use strict';

  $scope.newProject = $rootScope.activeProject;
  $scope.master = angular.copy($scope.newProject);

  $scope.updateOpenApiProject = function(form){
    if (form.$invalid) {
      return;
    }

    ProjectsServices.updateProject($scope.newProject)
      .then(function(result){
        return ProjectsServices.setProjectEnvironment(result.data)
          .then(function(project) {
            $rootScope.activeProject = project;
            $rootScope.workspaceDir = project;
          });
      })
      .then(function(){
        $rootScope.$emit('event:getProjects');
        $uibModalInstance.close();
      });
  };

  $scope.cancelProjectSettings = function(){
    angular.copy($scope.master, $scope.newProject);
    $uibModalInstance.close();
  }
}];
